import _extends from "@babel/runtime/helpers/extends";
/**
 * File: /src/components/Button/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 17-06-2022 07:34:18
 * Author: Clay Risser
 * -----
 * Last Modified: 13-12-2022 11:28:12
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/* eslint-disable @typescript-eslint/no-explicit-any */

import { MotiPressable } from 'moti/interactions';
import { Platform } from 'react-native';
import { styled, useSx } from 'dripsy';
import React, { forwardRef } from 'react';
import { MotiView } from 'moti';
import { BackgroundColorProvider, useAutoContrast } from '@risserlabs/auto-contrast';
import { useSplitProps } from './props';
import { Text } from '../Text';
import { bottomStyle, isText, passthroughStyle } from '../../util';
import { useCalculateMoti } from '../../hooks';
const themeKey = 'buttons';
const defaultOuterStyle = {
  appearance: 'none',
  bg: 'primary',
  border: 0,
  borderRadius: 4,
  userSelect: 'none'
};
const defaultTextStyle = {
  color: 'white',
  textAlign: 'center'
};
const defaultInnerStyle = {
  boxSizing: 'border-box',
  display: 'flex',
  flexDirection: 'column',
  px: 3,
  py: 2,
  flexShrink: 1,
  borderRadius: 4
};
const StyledMotiPressable = styled(MotiPressable, {
  themeKey,
  defaultVariant: 'primary'
})(defaultInnerStyle);
const StyledMotiView = styled(MotiView, {
  themeKey,
  defaultVariant: 'primary'
})(defaultInnerStyle);
const StyledText = styled(Text, {
  themeKey,
  defaultVariant: 'primary'
})(defaultTextStyle);
export const Button = /*#__PURE__*/forwardRef((props, ref) => {
  const sx = useAutoContrast(props, {
    ...defaultOuterStyle,
    ...defaultTextStyle
  }, themeKey);
  const calcSx = useSx();
  const {
    baseProps,
    baseStyle,
    baseSx,
    innerStyle,
    innerSx,
    motiPressableOuterStyle,
    motiPressableOuterSx,
    motiProps,
    sharedStyle,
    sharedSx,
    textProps,
    textStyle,
    textSx
  } = useSplitProps(props, {
    display: props.hidden ? 'none' : 'flex',
    ...sx
  });
  const {
    animate,
    from,
    exit
  } = useCalculateMoti(props, themeKey);
  const isMoti = !!Object.keys(motiProps).length;
  const platformStyle = Platform.select({
    web: {
      ...(props.onPress || props.accessibilityRole === 'link' || !props.disabled ? {
        cursor: 'pointer'
      } : {})
    }
  });
  const children = isText(props.children) ? /*#__PURE__*/React.createElement(StyledText, _extends({}, textProps, {
    sx: textSx,
    style: textStyle
  }), props.children) : props.children;
  const renderChildren = () => /*#__PURE__*/React.createElement(BackgroundColorProvider, _extends({}, props, {
    themeKey: themeKey,
    defaultStyle: defaultOuterStyle
  }), children);
  if (isMoti) {
    const outerStyle = {
      ...calcSx(defaultOuterStyle || {}, {
        themeKey
      }),
      ...calcSx(motiPressableOuterSx || {}, {
        themeKey
      }),
      ...calcSx(sharedSx || {}, {
        themeKey
      }),
      ...motiPressableOuterStyle,
      ...sharedStyle,
      ...platformStyle
    };
    return /*#__PURE__*/React.createElement(MotiPressable, _extends({}, baseProps, {
      containerStyle: outerStyle,
      ref: ref,
      sx: sharedSx,
      style: {
        ...passthroughStyle,
        ...sharedStyle
      }
    }), /*#__PURE__*/React.createElement(StyledMotiView, _extends({}, motiProps, {
      animate: animate,
      exit: exit,
      from: from,
      style: {
        ...bottomStyle,
        ...sharedStyle,
        ...baseStyle,
        ...innerStyle
      },
      sx: {
        ...sharedSx,
        ...baseSx,
        ...innerSx,
        px: 3
      }
    }), renderChildren()));
  }
  const outerStyle = {
    ...calcSx(defaultOuterStyle || {}, {
      themeKey
    }),
    ...calcSx(baseSx || {}, {
      themeKey
    }),
    ...calcSx(motiPressableOuterSx || {}, {
      themeKey
    }),
    ...calcSx(sharedSx || {}, {
      themeKey
    }),
    ...baseStyle,
    ...motiPressableOuterStyle,
    ...sharedStyle,
    ...platformStyle
  };
  return /*#__PURE__*/React.createElement(StyledMotiPressable, _extends({}, baseProps, {
    containerStyle: outerStyle,
    animate: animate,
    exit: exit,
    from: from,
    ref: ref,
    style: {
      ...bottomStyle,
      ...sharedStyle,
      ...innerStyle
    },
    sx: {
      ...sharedSx,
      ...innerSx
    }
  }), renderChildren());
});
//# sourceMappingURL=index.js.map