import _extends from "@babel/runtime/helpers/extends";
/**
 * File: /src/components/Embed/Embed.native.tsx
 * Project: @native-theme-ui/core
 * File Created: 18-07-2022 06:25:17
 * Author: Clay Risser
 * -----
 * Last Modified: 02-09-2022 06:24:55
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React from 'react';
import WebView from 'react-native-webview';
import { styled } from 'dripsy';
import { useCalculatedSx } from '@risserlabs/auto-contrast';
import YoutubeIframeThemed from './YoutubeIframeThemed';
import { AspectRatio } from '../AspectRatio';
import { useSplitProps } from './props';
const StyledWebView = styled(WebView)({});
export const Embed = props => {
  const sx = {
    border: props.frameBorder,
    ...useCalculatedSx(props.sx)
  };
  const {
    baseProps,
    iframeProps
  } = useSplitProps(props, sx);
  const youtubeVideoId = typeof props.src === 'string' && (props.src.indexOf('youtube.com/') > -1 || props.src.indexOf('youtube/') > -1) && Array.from(props.src.match(/[^/]+$/g) || []).join('').trim() || null;
  function renderWebView() {
    if (!props.src) return [];
    if (youtubeVideoId) {
      const youtubeIframeThemedProps = {
        ...props
      };
      delete youtubeIframeThemedProps.src;
      return /*#__PURE__*/React.createElement(YoutubeIframeThemed, {
        initialPlayerParams: {
          ...(typeof iframeProps.allowFullScreen === 'boolean' ? {
            preventFullScreen: !iframeProps.allowFullScreen
          } : {})
        },
        videoId: youtubeVideoId,
        useLocalHTML: true,
        style: {
          height: '100%',
          width: '100%'
        }
      });
    }
    return /*#__PURE__*/React.createElement(StyledWebView, {
      source: {
        uri: props.src
      },
      originWhitelist: ['*'],
      sx: {
        width: sx.width,
        height: sx.height
      }
    });
  }
  return /*#__PURE__*/React.createElement(AspectRatio, _extends({}, baseProps, {
    sx: sx
  }), renderWebView());
};
Embed.defaultProps = {
  ratio: 16 / 9
};
//# sourceMappingURL=Embed.native.js.map