import _extends from "@babel/runtime/helpers/extends";
/**
 * File: /src/components/Textarea/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 09-11-2022 12:47:58
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useCallback, useState } from 'react';
import { StyleSheet, Platform } from 'react-native';
import { styled } from 'dripsy';
import { useAutoContrast } from '@risserlabs/auto-contrast';
import { Input } from '../Input';
const defaultStyle = {
  color: 'text',
  overflow: 'hidden'
};
const themeKey = 'forms';
const StyledInput = styled(Input, {
  themeKey,
  defaultVariant: 'textarea'
})(defaultStyle);
export const Textarea = props => {
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  const [scrollHeight, setScrollHeight] = useState();
  const style = StyleSheet.flatten(props.style) || {};
  const handleChange = useCallback(e => {
    if (Platform.OS === 'web') {
      setScrollHeight(`${(e.target.scrollHeight || 0) + (e.target.offsetHeight || 0) - (e.target.clientHeight || 0)}px`);
    }
    if (props.onChange) props.onChange(e);
  }, [props.onChange]);
  return /*#__PURE__*/React.createElement(StyledInput
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  , _extends({}, props, {
    numberOfLines: props.numberOfLines ?? props.rows,
    onChange: handleChange,
    multiline: true,
    sx: sx,
    style: {
      ...(Platform.select({
        web: {
          height: scrollHeight
        }
      }) || {}),
      ...style
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
    }
  }));
};

Textarea.defaultProps = {
  rows: 4,
  textAlignVertical: 'top'
};
//# sourceMappingURL=index.js.map