(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "@babel/runtime/helpers/extends", "react", "moti/interactions", "moti", "dripsy", "react-native", "@risserlabs/auto-contrast", "./props", "../Text", "../../util", "../../hooks"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("@babel/runtime/helpers/extends"), require("react"), require("moti/interactions"), require("moti"), require("dripsy"), require("react-native"), require("@risserlabs/auto-contrast"), require("./props"), require("../Text"), require("../../util"), require("../../hooks"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global._extends, global.react, global.interactions, global.moti, global.dripsy, global.reactNative, global.autoContrast, global.props, global.Text, global.util, global.hooks);
    global.index = mod.exports;
  }
})(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : this, function (_exports, _extends2, _react, _interactions, _moti, _dripsy, _reactNative, _autoContrast, _props, _Text, _util, _hooks) {
  "use strict";

  var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.Box = void 0;
  _extends2 = _interopRequireDefault(_extends2);
  _react = _interopRequireDefault(_react);
  /**
   * File: /src/components/Box/index.tsx
   * Project: @native-theme-ui/core
   * File Created: 13-06-2022 00:51:44
   * Author: Clay Risser
   * -----
   * Last Modified: 24-11-2022 14:34:11
   * Modified By: Clay Risser
   * -----
   * Risser Labs LLC (c) Copyright 2021 - 2022
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   *     http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /* eslint-disable @typescript-eslint/no-explicit-any */

  const themeKey = 'variants';
  const defaultOuterStyle = {
    boxSizing: 'border-box',
    flexShrink: 1
  };
  const defaultInnerStyle = {
    boxSizing: 'border-box',
    display: 'flex',
    flexDirection: 'column',
    flexShrink: 1
  };
  const StyledView = (0, _dripsy.styled)(_reactNative.View, {
    themeKey
  })(defaultInnerStyle);
  const StyledMotiPressable = (0, _dripsy.styled)(_interactions.MotiPressable, {
    themeKey
  })(defaultInnerStyle);
  const StyledMotiView = (0, _dripsy.styled)(_moti.MotiView, {
    themeKey
  })(defaultInnerStyle);
  const Box = props => {
    const sx = (0, _autoContrast.useAutoContrast)(props, {}, themeKey);
    const calcSx = (0, _dripsy.useSx)();
    const {
      baseProps,
      baseStyle,
      baseSx,
      innerStyle,
      innerSx,
      motiPressableOuterStyle,
      motiPressableOuterSx,
      motiProps,
      pressableProps,
      sharedStyle,
      sharedSx,
      textProps,
      textStyle,
      textSx
    } = (0, _props.useSplitProps)(props, sx);
    const isPressable = !!Object.keys(pressableProps).length;
    const isMoti = !!Object.keys(motiProps).length;
    const {
      animate,
      from,
      exit
    } = (0, _hooks.useCalculateMoti)(props, themeKey, isMoti);
    const children = (0, _util.isText)(props.children) ? /*#__PURE__*/_react.default.createElement(_Text.Text, (0, _extends2.default)({}, textProps, {
      sx: textSx,
      style: textStyle
    }), props.children) : props.children;
    const renderChildren = () => /*#__PURE__*/_react.default.createElement(_autoContrast.BackgroundColorProvider, (0, _extends2.default)({}, props, {
      themeKey: themeKey
    }), children);
    if (isPressable) {
      if (isMoti) {
        const outerStyle = {
          ...defaultOuterStyle,
          ...calcSx(motiPressableOuterSx || {}, {
            themeKey
          }),
          ...calcSx(sharedSx || {}, {
            themeKey
          }),
          ...motiPressableOuterStyle,
          ...sharedStyle
        };
        return /*#__PURE__*/_react.default.createElement(_interactions.MotiPressable, (0, _extends2.default)({}, pressableProps, {
          containerStyle: outerStyle,
          sx: sharedSx,
          style: {
            ..._util.passthroughStyle,
            ...sharedStyle
          }
        }), /*#__PURE__*/_react.default.createElement(StyledMotiView, (0, _extends2.default)({}, baseProps, motiProps, {
          animate: animate,
          exit: exit,
          from: from,
          style: {
            ..._util.bottomStyle,
            ...baseStyle,
            ...sharedStyle,
            ...innerStyle
          },
          sx: {
            ...baseSx,
            ...sharedSx,
            ...innerSx
          }
        }), renderChildren()));
      }
      const outerStyle = {
        ...defaultOuterStyle,
        ...calcSx(baseSx || {}, {
          themeKey
        }),
        ...calcSx(motiPressableOuterSx || {}, {
          themeKey
        }),
        ...calcSx(sharedSx || {}, {
          themeKey
        }),
        ...motiPressableOuterStyle,
        ...baseStyle,
        ...sharedStyle
      };
      return /*#__PURE__*/_react.default.createElement(StyledMotiPressable, (0, _extends2.default)({}, baseProps, pressableProps, {
        containerStyle: outerStyle,
        style: {
          ..._util.bottomStyle,
          ...sharedStyle,
          ...innerStyle
        },
        sx: {
          ...sharedSx,
          ...innerSx
        }
      }), renderChildren());
    }
    if (isMoti) {
      return /*#__PURE__*/_react.default.createElement(StyledMotiView, (0, _extends2.default)({}, baseProps, motiProps, {
        animate: animate,
        exit: exit,
        from: from,
        style: {
          ...baseStyle,
          ...innerStyle,
          ...motiPressableOuterStyle,
          ...sharedStyle
        },
        sx: {
          ...baseSx,
          ...innerSx,
          ...motiPressableOuterSx,
          ...sharedSx
        }
      }), renderChildren());
    }
    return /*#__PURE__*/_react.default.createElement(StyledView, (0, _extends2.default)({}, baseProps, {
      style: {
        ...baseStyle,
        ...innerStyle,
        ...motiPressableOuterStyle,
        ...sharedStyle
      },
      sx: {
        ...baseSx,
        ...innerSx,
        ...motiPressableOuterSx,
        ...sharedSx
      }
    }), renderChildren());
  };
  _exports.Box = Box;
});
//# sourceMappingURL=index.js.map