(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "@babel/runtime/helpers/extends", "moti/interactions", "react-native", "dripsy", "react", "moti", "@risserlabs/auto-contrast", "./props", "../Text", "../../util", "../../hooks"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("@babel/runtime/helpers/extends"), require("moti/interactions"), require("react-native"), require("dripsy"), require("react"), require("moti"), require("@risserlabs/auto-contrast"), require("./props"), require("../Text"), require("../../util"), require("../../hooks"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global._extends, global.interactions, global.reactNative, global.dripsy, global.react, global.moti, global.autoContrast, global.props, global.Text, global.util, global.hooks);
    global.index = mod.exports;
  }
})(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : this, function (_exports, _extends2, _interactions, _reactNative, _dripsy, _react, _moti, _autoContrast, _props, _Text, _util, _hooks) {
  "use strict";

  var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.Button = void 0;
  _extends2 = _interopRequireDefault(_extends2);
  _react = _interopRequireWildcard(_react);
  function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
  function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
  /**
   * File: /src/components/Button/index.tsx
   * Project: @native-theme-ui/core
   * File Created: 17-06-2022 07:34:18
   * Author: Clay Risser
   * -----
   * Last Modified: 13-12-2022 11:28:12
   * Modified By: Clay Risser
   * -----
   * Risser Labs LLC (c) Copyright 2021 - 2022
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   *     http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /* eslint-disable @typescript-eslint/no-explicit-any */

  const themeKey = 'buttons';
  const defaultOuterStyle = {
    appearance: 'none',
    bg: 'primary',
    border: 0,
    borderRadius: 4,
    userSelect: 'none'
  };
  const defaultTextStyle = {
    color: 'white',
    textAlign: 'center'
  };
  const defaultInnerStyle = {
    boxSizing: 'border-box',
    display: 'flex',
    flexDirection: 'column',
    px: 3,
    py: 2,
    flexShrink: 1,
    borderRadius: 4
  };
  const StyledMotiPressable = (0, _dripsy.styled)(_interactions.MotiPressable, {
    themeKey,
    defaultVariant: 'primary'
  })(defaultInnerStyle);
  const StyledMotiView = (0, _dripsy.styled)(_moti.MotiView, {
    themeKey,
    defaultVariant: 'primary'
  })(defaultInnerStyle);
  const StyledText = (0, _dripsy.styled)(_Text.Text, {
    themeKey,
    defaultVariant: 'primary'
  })(defaultTextStyle);
  const Button = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => {
    const sx = (0, _autoContrast.useAutoContrast)(props, {
      ...defaultOuterStyle,
      ...defaultTextStyle
    }, themeKey);
    const calcSx = (0, _dripsy.useSx)();
    const {
      baseProps,
      baseStyle,
      baseSx,
      innerStyle,
      innerSx,
      motiPressableOuterStyle,
      motiPressableOuterSx,
      motiProps,
      sharedStyle,
      sharedSx,
      textProps,
      textStyle,
      textSx
    } = (0, _props.useSplitProps)(props, {
      display: props.hidden ? 'none' : 'flex',
      ...sx
    });
    const {
      animate,
      from,
      exit
    } = (0, _hooks.useCalculateMoti)(props, themeKey);
    const isMoti = !!Object.keys(motiProps).length;
    const platformStyle = _reactNative.Platform.select({
      web: {
        ...(props.onPress || props.accessibilityRole === 'link' || !props.disabled ? {
          cursor: 'pointer'
        } : {})
      }
    });
    const children = (0, _util.isText)(props.children) ? /*#__PURE__*/_react.default.createElement(StyledText, (0, _extends2.default)({}, textProps, {
      sx: textSx,
      style: textStyle
    }), props.children) : props.children;
    const renderChildren = () => /*#__PURE__*/_react.default.createElement(_autoContrast.BackgroundColorProvider, (0, _extends2.default)({}, props, {
      themeKey: themeKey,
      defaultStyle: defaultOuterStyle
    }), children);
    if (isMoti) {
      const outerStyle = {
        ...calcSx(defaultOuterStyle || {}, {
          themeKey
        }),
        ...calcSx(motiPressableOuterSx || {}, {
          themeKey
        }),
        ...calcSx(sharedSx || {}, {
          themeKey
        }),
        ...motiPressableOuterStyle,
        ...sharedStyle,
        ...platformStyle
      };
      return /*#__PURE__*/_react.default.createElement(_interactions.MotiPressable, (0, _extends2.default)({}, baseProps, {
        containerStyle: outerStyle,
        ref: ref,
        sx: sharedSx,
        style: {
          ..._util.passthroughStyle,
          ...sharedStyle
        }
      }), /*#__PURE__*/_react.default.createElement(StyledMotiView, (0, _extends2.default)({}, motiProps, {
        animate: animate,
        exit: exit,
        from: from,
        style: {
          ..._util.bottomStyle,
          ...sharedStyle,
          ...baseStyle,
          ...innerStyle
        },
        sx: {
          ...sharedSx,
          ...baseSx,
          ...innerSx,
          px: 3
        }
      }), renderChildren()));
    }
    const outerStyle = {
      ...calcSx(defaultOuterStyle || {}, {
        themeKey
      }),
      ...calcSx(baseSx || {}, {
        themeKey
      }),
      ...calcSx(motiPressableOuterSx || {}, {
        themeKey
      }),
      ...calcSx(sharedSx || {}, {
        themeKey
      }),
      ...baseStyle,
      ...motiPressableOuterStyle,
      ...sharedStyle,
      ...platformStyle
    };
    return /*#__PURE__*/_react.default.createElement(StyledMotiPressable, (0, _extends2.default)({}, baseProps, {
      containerStyle: outerStyle,
      animate: animate,
      exit: exit,
      from: from,
      ref: ref,
      style: {
        ..._util.bottomStyle,
        ...sharedStyle,
        ...innerStyle
      },
      sx: {
        ...sharedSx,
        ...innerSx
      }
    }), renderChildren());
  });
  _exports.Button = Button;
});
//# sourceMappingURL=index.js.map