(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "@babel/runtime/helpers/extends", "react", "react-native-reanimated", "react-native-svg", "dripsy", "@risserlabs/auto-contrast", "../Box"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("@babel/runtime/helpers/extends"), require("react"), require("react-native-reanimated"), require("react-native-svg"), require("dripsy"), require("@risserlabs/auto-contrast"), require("../Box"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global._extends, global.react, global.reactNativeReanimated, global.reactNativeSvg, global.dripsy, global.autoContrast, global.Box);
    global.index = mod.exports;
  }
})(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : this, function (_exports, _extends2, _react, _reactNativeReanimated, _reactNativeSvg, _dripsy, _autoContrast, _Box) {
  "use strict";

  var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.Spinner = void 0;
  _extends2 = _interopRequireDefault(_extends2);
  _react = _interopRequireDefault(_react);
  /**
   * File: /src/components/Spinner/index.tsx
   * Project: @native-theme-ui/core
   * File Created: 13-06-2022 00:51:44
   * Author: Clay Risser
   * -----
   * Last Modified: 24-11-2022 12:18:27
   * Modified By: Clay Risser
   * -----
   * Risser Labs LLC (c) Copyright 2021 - 2022
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   *     http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */
  /* eslint-disable @typescript-eslint/no-non-null-assertion,@typescript-eslint/no-explicit-any */

  const themeKey = 'variants';
  const defaultStyle = {
    color: 'primary',
    overflow: 'visible'
  };
  const defaultBoxStyle = {
    justifyContent: 'center',
    alignItems: 'center'
  };
  const StyledSvg = (0, _dripsy.styled)(_reactNativeSvg.Svg, {
    themeKey
  })(defaultStyle);
  const StyledBox = (0, _dripsy.styled)(_Box.Box, {
    themeKey
  })(_ref => {
    let {
      size
    } = _ref;
    return {
      ...defaultStyle,
      ...defaultBoxStyle,
      width: size,
      height: size
    };
  });
  const Spinner = props => {
    const sx = (0, _autoContrast.useAutoContrast)(props, defaultStyle, themeKey);
    const r = 16 - props.strokeWidth;
    const C = 2 * r * Math.PI;
    const offset = C - 1 / 4 * C;
    const svgProps = {
      fill: 'none',
      height: props.size,
      stroke: 'currentColor',
      strokeWidth: props.strokeWidth,
      viewBox: '0 0 32 32',
      width: props.size,
      style: {
        color: sx.color
      }
    };
    return /*#__PURE__*/_react.default.createElement(StyledBox, (0, _extends2.default)({}, props, {
      sx: sx
    }), /*#__PURE__*/_react.default.createElement(StyledSvg, (0, _extends2.default)({}, svgProps, {
      style: {
        opacity: 1 / 8
      }
    }), /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Circle, {
      cx: 16,
      cy: 16,
      r: r
    })), /*#__PURE__*/_react.default.createElement(_Box.Box, {
      from: {
        rotate: '0deg'
      },
      animate: {
        rotate: '360deg'
      },
      transition: {
        duration: props.duration,
        easing: _reactNativeReanimated.Easing.linear,
        loop: true,
        repeatReverse: false,
        type: 'timing'
      },
      style: {
        borderRadius: 9999,
        overflow: 'hidden',
        position: 'absolute'
      }
    }, /*#__PURE__*/_react.default.createElement(StyledSvg, svgProps, /*#__PURE__*/_react.default.createElement(_reactNativeSvg.Circle, {
      cx: 16,
      cy: 16,
      r: r,
      strokeDasharray: C,
      strokeDashoffset: offset
    }))));
  };
  _exports.Spinner = Spinner;
  Spinner.defaultProps = {
    duration: 500,
    size: 48,
    strokeWidth: 4
  };
});
//# sourceMappingURL=index.js.map